==> lighthouse-2.4.0.tgz: package/lighthouse-core/audits/accessibility/valid-lang.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * @fileoverview Ensures lang attributes have valid values.
 * See base class in axe-audit.js for audit() implementation.
 */

const AxeAudit = require('./axe-audit');

class ValidLang extends AxeAudit {
  /**
   * @return {!AuditMeta}
   */
  static get meta() {
    return {
      category: 'Accessibility',
      name: 'valid-lang',
      description: '`[lang]` attributes have a valid value.',
      failureDescription: '`[lang]` attributes do not have a valid value.',
      helpText: 'Specifying a valid [BCP 47 language](https://www.w3.org/International/questions/qa-choosing-language-tags#question) ' +
          'on elements helps ensure that text is pronounced correctly by a screen reader. ' +
          '[Learn more](https://dequeuniversity.com/rules/axe/2.2/valid-lang?application=lighthouse).',
      requiredArtifacts: ['Accessibility']
    };
  }
}

module.exports = ValidLang;

==> lighthouse-2.5.0.tgz: package/lighthouse-core/audits/accessibility/valid-lang.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * @fileoverview Ensures lang attributes have valid values.
 * See base class in axe-audit.js for audit() implementation.
 */

const AxeAudit = require('./axe-audit');

class ValidLang extends AxeAudit {
  /**
   * @return {!AuditMeta}
   */
  static get meta() {
    return {
      category: 'Accessibility',
      name: 'valid-lang',
      description: '`[lang]` attributes have a valid value.',
      failureDescription: '`[lang]` attributes do not have a valid value.',
      helpText: 'Specifying a valid [BCP 47 language](https://www.w3.org/International/questions/qa-choosing-language-tags#question) ' +
          'on elements helps ensure that text is pronounced correctly by a screen reader. ' +
          '[Learn more](https://dequeuniversity.com/rules/axe/2.2/valid-lang?application=lighthouse).',
      requiredArtifacts: ['Accessibility'],
    };
  }
}

module.exports = ValidLang;
